<div align="center">
    <a href="https://www.promptmodel.run">
        <img src="https://i.imgur.com/f3MHyH3.png" title="Logo" style="width: 160px; margin-bottom: 16px;" />
    </a>
    <h1>Promptmodel</h1>
    <p>
        <h3>Prompt & model versioning on the cloud, built for developers.</h3>
        <p>
            We are currently on <strong>closed alpha</strong>.
            <a href="https://formless.ai/c/RtUfMCsh9YSs">Request access 🚀</a>
        </p>
    </p>
    <div>
        <a href="https://pypi.org/project/promptmodel" target="_blank">
            <img src="https://img.shields.io/pypi/v/promptmodel.svg" alt="PyPI Version">
        </a>
        <a href="https://discord.gg/2Y36M36tZf" target="_blank">
            <img src="https://dcbadge.vercel.app/api/server/dVTtyEU4?style=flat">
        </a>
    </div>
</div>

## Installation

```bash
pip install promptmodel
```

## Documentation

You can find our full documentation [here](https://www.promptmodel.run/docs/introduction).
